==> blender_2.61.orig.tar.bz2: blender-2.61/source/blender/editors/include/ED_datafiles.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2008 Blender Foundation.
 * All rights reserved.
 *
 * 
 * Contributor(s): Blender Foundation
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file ED_datafiles.h
 *  \ingroup editors
 */

#ifndef ED_DATAFILES_H
#define ED_DATAFILES_H

/* Datafiles embedded in Blender */

extern int datatoc_startup_blend_size;
extern char datatoc_startup_blend[];

extern int datatoc_blender_icons_png_size;
extern char datatoc_blender_icons_png[];

extern int datatoc_prvicons_size;
extern char datatoc_prvicons[];

extern int datatoc_splash_png_size;
extern char datatoc_splash_png[];

extern int datatoc_Bfont_size;
extern char datatoc_Bfont[];

extern int datatoc_bfont_ttf_size;
extern char datatoc_bfont_ttf[];

extern int datatoc_bmonofont_ttf_size;
extern char datatoc_bmonofont_ttf[];

/* Brush icon datafiles */
/* TODO: this could be simplified by putting all
   the brush icons in one file */
extern int datatoc_add_png_size;
extern char datatoc_add_png[];

extern int datatoc_blob_png_size;
extern char datatoc_blob_png[];

extern int datatoc_blur_png_size;
extern char datatoc_blur_png[];

extern int datatoc_clay_png_size;
extern char datatoc_clay_png[];

extern int datatoc_clone_png_size;
extern char datatoc_clone_png[];

extern int datatoc_crease_png_size;
extern char datatoc_crease_png[];

extern int datatoc_darken_png_size;
extern char datatoc_darken_png[];

extern int datatoc_draw_png_size;
extern char datatoc_draw_png[];

extern int datatoc_fill_png_size;
extern char datatoc_fill_png[];

extern int datatoc_flatten_png_size;
extern char datatoc_flatten_png[];

extern int datatoc_grab_png_size;
extern char datatoc_grab_png[];

extern int datatoc_inflate_png_size;
extern char datatoc_inflate_png[];

extern int datatoc_layer_png_size;
extern char datatoc_layer_png[];

extern int datatoc_lighten_png_size;
extern char datatoc_lighten_png[];

extern int datatoc_mix_png_size;
extern char datatoc_mix_png[];

extern int datatoc_multiply_png_size;
extern char datatoc_multiply_png[];

extern int datatoc_nudge_png_size;
extern char datatoc_nudge_png[];

extern int datatoc_pinch_png_size;
extern char datatoc_pinch_png[];

extern int datatoc_scrape_png_size;
extern char datatoc_scrape_png[];

extern int datatoc_smear_png_size;
extern char datatoc_smear_png[];

extern int datatoc_smooth_png_size;
extern char datatoc_smooth_png[];

extern int datatoc_snake_hook_png_size;
extern char datatoc_snake_hook_png[];

extern int datatoc_soften_png_size;
extern char datatoc_soften_png[];

extern int datatoc_subtract_png_size;
extern char datatoc_subtract_png[];

extern int datatoc_texdraw_png_size;
extern char datatoc_texdraw_png[];

extern int datatoc_thumb_png_size;
extern char datatoc_thumb_png[];

extern int datatoc_twist_png_size;
extern char datatoc_twist_png[];

extern int datatoc_vertexdraw_png_size;
extern char datatoc_vertexdraw_png[];


#endif /* ED_DATAFILES_H */

==> blender_2.63a.orig.tar.bz2: blender-2.63a/source/blender/editors/include/ED_datafiles.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2008 Blender Foundation.
 * All rights reserved.
 *
 * 
 * Contributor(s): Blender Foundation
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file ED_datafiles.h
 *  \ingroup editors
 */

#ifndef __ED_DATAFILES_H__
#define __ED_DATAFILES_H__

/* Datafiles embedded in Blender */

extern int datatoc_startup_blend_size;
extern char datatoc_startup_blend[];

extern int datatoc_blender_icons_png_size;
extern char datatoc_blender_icons_png[];

extern int datatoc_prvicons_size;
extern char datatoc_prvicons[];

extern int datatoc_splash_png_size;
extern char datatoc_splash_png[];

extern int datatoc_Bfont_size;
extern char datatoc_Bfont[];

extern int datatoc_bfont_ttf_size;
extern char datatoc_bfont_ttf[];

extern int datatoc_bmonofont_ttf_size;
extern char datatoc_bmonofont_ttf[];

/* Brush icon datafiles */
/* TODO: this could be simplified by putting all
 * the brush icons in one file */
extern int datatoc_add_png_size;
extern char datatoc_add_png[];

extern int datatoc_blob_png_size;
extern char datatoc_blob_png[];

extern int datatoc_blur_png_size;
extern char datatoc_blur_png[];

extern int datatoc_clay_png_size;
extern char datatoc_clay_png[];

extern int datatoc_claystrips_png_size;
extern char datatoc_claystrips_png[];

extern int datatoc_clone_png_size;
extern char datatoc_clone_png[];

extern int datatoc_crease_png_size;
extern char datatoc_crease_png[];

extern int datatoc_darken_png_size;
extern char datatoc_darken_png[];

extern int datatoc_draw_png_size;
extern char datatoc_draw_png[];

extern int datatoc_fill_png_size;
extern char datatoc_fill_png[];

extern int datatoc_flatten_png_size;
extern char datatoc_flatten_png[];

extern int datatoc_grab_png_size;
extern char datatoc_grab_png[];

extern int datatoc_inflate_png_size;
extern char datatoc_inflate_png[];

extern int datatoc_layer_png_size;
extern char datatoc_layer_png[];

extern int datatoc_lighten_png_size;
extern char datatoc_lighten_png[];

extern int datatoc_mix_png_size;
extern char datatoc_mix_png[];

extern int datatoc_multiply_png_size;
extern char datatoc_multiply_png[];

extern int datatoc_nudge_png_size;
extern char datatoc_nudge_png[];

extern int datatoc_pinch_png_size;
extern char datatoc_pinch_png[];

extern int datatoc_scrape_png_size;
extern char datatoc_scrape_png[];

extern int datatoc_smear_png_size;
extern char datatoc_smear_png[];

extern int datatoc_smooth_png_size;
extern char datatoc_smooth_png[];

extern int datatoc_snake_hook_png_size;
extern char datatoc_snake_hook_png[];

extern int datatoc_soften_png_size;
extern char datatoc_soften_png[];

extern int datatoc_subtract_png_size;
extern char datatoc_subtract_png[];

extern int datatoc_texdraw_png_size;
extern char datatoc_texdraw_png[];

extern int datatoc_thumb_png_size;
extern char datatoc_thumb_png[];

extern int datatoc_twist_png_size;
extern char datatoc_twist_png[];

extern int datatoc_vertexdraw_png_size;
extern char datatoc_vertexdraw_png[];


#endif /* __ED_DATAFILES_H__ */
